mot package
===========

Subpackages
-----------

.. toctree::

    mot.cl_routines
    mot.lib
    mot.library_functions
    mot.optimize
    mot.sample

Submodules
----------

mot.configuration module
------------------------

.. automodule:: mot.configuration
    :members:
    :undoc-members:
    :show-inheritance:

mot.mcmc_diagnostics module
---------------------------

.. automodule:: mot.mcmc_diagnostics
    :members:
    :undoc-members:
    :show-inheritance:

mot.random module
-----------------

.. automodule:: mot.random
    :members:
    :undoc-members:
    :show-inheritance:

mot.stats module
----------------

.. automodule:: mot.stats
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mot
    :members:
    :undoc-members:
    :show-inheritance:
